#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: sda_fabric_devices
short_description: Resource module for Sda Fabric Devices
description:
  - Manage operations create, update and delete of the resource Sda Fabric Devices.
  - Adds fabric devices based on user input.
  - Deletes a fabric device based on id.
  - Deletes fabric devices based on user input.
  - Updates fabric devices based on user input.
version_added: '6.14.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  deviceRoles:
    description: DeviceRoles query parameter. Device roles of the fabric device. Allowed values are CONTROL_PLANE_NODE, EDGE_NODE,
      BORDER_NODE, WIRELESS_CONTROLLER_NODE.
    type: str
  fabricId:
    description: FabricId query parameter. ID of the fabric this device belongs to.
    type: str
  id:
    description: Id path parameter. ID of the fabric device.
    type: str
  networkDeviceId:
    description: NetworkDeviceId query parameter. Network device ID of the fabric device.
    type: str
  payload:
    description: Sda Fabric Devices's payload.
    elements: dict
    suboptions:
      borderDeviceSettings:
        description: Sda Fabric Devices's borderDeviceSettings.
        suboptions:
          borderTypes:
            description: List of the border types of the fabric device. Allowed values are LAYER_2, LAYER_3.
            elements: str
            type: list
          layer3Settings:
            description: Sda Fabric Devices's layer3Settings.
            suboptions:
              borderPriority:
                description: Border priority of the fabric border device. Allowed range is 1-9. A lower value indicates higher
                  priority. E.g., a priority of 1 takes precedence over 5. Default priority would be set to 10.
                type: int
              importExternalRoutes:
                description: Set this to import external routes from other routing protocols (such as BGP) to the fabric control
                  plane.
                type: bool
              isDefaultExit:
                description: Set this to make the fabric border device the gateway of last resort for this site. Any unknown
                  traffic will be sent to this fabric border device from edge nodes.
                type: bool
              localAutonomousSystemNumber:
                description: BGP Local autonomous system number of the fabric border device. Allowed range is 1 to 4294967295.
                type: str
              prependAutonomousSystemCount:
                description: Prepend autonomous system count of the fabric border device. Allowed range is 1 to 10.
                type: int
            type: dict
        type: dict
      deviceRoles:
        description: List of the roles of the fabric device. Allowed values are CONTROL_PLANE_NODE, EDGE_NODE, BORDER_NODE,
          WIRELESS_CONTROLLER_NODE.
        elements: str
        type: list
      fabricId:
        description: ID of the fabric of this fabric device.
        type: str
      networkDeviceId:
        description: Network device ID of the fabric device.
        type: str
    type: list
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for SDA AddFabricDevices
    description: Complete reference of the AddFabricDevices API.
    link: https://developer.cisco.com/docs/dna-center/#!add-fabric-devices
  - name: Cisco DNA Center documentation for SDA DeleteFabricDeviceById
    description: Complete reference of the DeleteFabricDeviceById API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-fabric-device-by-id
  - name: Cisco DNA Center documentation for SDA DeleteFabricDevices
    description: Complete reference of the DeleteFabricDevices API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-fabric-devices
  - name: Cisco DNA Center documentation for SDA UpdateFabricDevices
    description: Complete reference of the UpdateFabricDevices API.
    link: https://developer.cisco.com/docs/dna-center/#!update-fabric-devices
notes:
  - SDK Method used are
    sda.Sda.add_fabric_devices,
    sda.Sda.delete_fabric_device_by_id,
    sda.Sda.update_fabric_devices,
  - Paths used are
    post /dna/intent/api/v1/sda/fabricDevices,
    delete /dna/intent/api/v1/sda/fabricDevices,
    delete /dna/intent/api/v1/sda/fabricDevices/{id},
    put /dna/intent/api/v1/sda/fabricDevices,
"""

EXAMPLES = r"""
---
- name: Delete all
  cisco.dnac.sda_fabric_devices:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    deviceRoles: string
    fabricId: string
    networkDeviceId: string
- name: Create
  cisco.dnac.sda_fabric_devices:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    payload:
      - borderDeviceSettings:
          borderTypes:
            - string
          layer3Settings:
            borderPriority: 0
            importExternalRoutes: true
            isDefaultExit: true
            localAutonomousSystemNumber: string
            prependAutonomousSystemCount: 0
        deviceRoles:
          - string
        fabricId: string
        networkDeviceId: string
- name: Update all
  cisco.dnac.sda_fabric_devices:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    payload:
      - borderDeviceSettings:
          borderTypes:
            - string
          layer3Settings:
            borderPriority: 0
            importExternalRoutes: true
            isDefaultExit: true
            localAutonomousSystemNumber: string
            prependAutonomousSystemCount: 0
        deviceRoles:
          - string
        fabricId: string
        id: string
        networkDeviceId: string
- name: Delete by id
  cisco.dnac.sda_fabric_devices:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    id: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_bugs_results_network_devices_info
short_description: Information module for Network Bugs Results Network Devices
description:
  - Get all Network Bugs Results Network Devices.
  - Get Network Bugs Results Network Devices by id.
  - Get network bug device by device id.
  - Get network bug devices.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  networkDeviceId:
    description:
      - NetworkDeviceId query parameter. Id of the network device.
    type: str
  scanMode:
    description:
      - >
        ScanMode query parameter. Mode or the criteria using which the network device was scanned. Available
        values ESSENTIALS, ADVANTAGE, CX_CLOUD, NOT_AVAILABLE.
    type: str
  scanStatus:
    description:
      - >
        ScanStatus query parameter. Status of the scan on the network device. Available values NOT_SCANNED,
        IN_PROGRESS, SUCCESS, FAILED, FALL_BACK.
    type: str
  bugCount:
    description:
      - BugCount query parameter. Return network devices with bugCount greater than this bugCount.
    type: float
  offset:
    description:
      - >
        Offset query parameter. The first record to show for this page; the first record is numbered 1. Default
        value is 1.
    type: int
  limit:
    description:
      - >
        Limit query parameter. The number of records to show for this page. Minimum value is 1. Maximum value is
        500. Default value is 500.
    type: int
  sortBy:
    description:
      - SortBy query parameter. A property within the response to sort by.
    type: str
  order:
    description:
      - >
        Order query parameter. Whether ascending or descending order should be used to sort the response.
        Available values asc, desc. Default value is asc.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Compliance GetNetworkBugDeviceByDeviceId
    description: Complete reference of the GetNetworkBugDeviceByDeviceId API.
    link: https://developer.cisco.com/docs/dna-center/#!get-network-bug-device-by-device-id
  - name: Cisco DNA Center documentation for Compliance GetNetworkBugDevices
    description: Complete reference of the GetNetworkBugDevices API.
    link: https://developer.cisco.com/docs/dna-center/#!get-network-bug-devices
notes:
  - SDK Method used are
    compliance.Compliance.get_network_bug_device_by_device_id,
    compliance.Compliance.get_network_bug_devices,
  - Paths used are
    get /dna/intent/api/v1/networkBugs/results/networkDevices,
    get /dna/intent/api/v1/networkBugs/results/networkDevices/{networkDeviceId},
"""

EXAMPLES = r"""
---
- name: Get all Network Bugs Results Network Devices
  cisco.dnac.network_bugs_results_network_devices_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    networkDeviceId: string
    scanMode: string
    scanStatus: string
    bugCount: 0
    offset: 0
    limit: 0
    sortBy: string
    order: string
  register: result
- name: Get Network Bugs Results Network Devices by id
  cisco.dnac.network_bugs_results_network_devices_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    networkDeviceId: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: list
  elements: dict
  sample: >
    [
      {
        "response": {
          "networkDeviceId": "string",
          "bugCount": 0,
          "scanMode": "string",
          "scanStatus": "string",
          "comments": "string",
          "lastScanTime": 0
        },
        "version": "string"
      }
    ]
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: releases_info
short_description: Information module for Releases
description:
  - Get all Releases.
  - This api is used to get all available release.
version_added: '6.46.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for System Software Upgrade GetAllRelease
    description: Complete reference of the GetAllRelease API.
    link: https://developer.cisco.com/docs/dna-center/#!get-all-release
notes:
  - SDK Method used are
    system_software_upgrade.SystemSoftwareUpgrade.get_all_release,
  - Paths used are
    get /dna/system/api/v1/releases,
"""

EXAMPLES = r"""
---
- name: Get all Releases
  cisco.dnac.releases_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "attributes": {
            "hidden": "string",
            "replaces": "string"
          },
          "description": "string",
          "displayName": "string",
          "displayVersion": "string",
          "name": "string",
          "releaseNotesUrl": "string",
          "version": "string"
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wireless_provision_device_create
short_description: Resource module for Wireless Provision Device Create
description:
  - Manage operation create of the resource Wireless Provision Device Create.
  - Provision wireless device.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  payload:
    description: Wireless Provision Device Create's payload.
    elements: dict
    suboptions:
      deviceName:
        description: Controller Name.
        type: str
      dynamicInterfaces:
        description: Wireless Provision Device Create's dynamicInterfaces.
        elements: dict
        suboptions:
          interfaceGateway:
            description: Interface Gateway. Required for AireOS.
            type: str
          interfaceIPAddress:
            description: Interface IP Address. Required for AireOS.
            type: str
          interfaceName:
            description: Interface Name. Required for both AireOS and EWLC.
            type: str
          interfaceNetmaskInCIDR:
            description: Interface Netmask In CIDR. Required for AireOS.
            type: int
          lagOrPortNumber:
            description: Lag Or Port Number. Required for AireOS.
            type: int
          vlanId:
            description: VLAN ID. Required for both AireOS and EWLC.
            type: int
        type: list
      managedAPLocations:
        description: List of managed AP locations (Site Hierarchies).
        elements: str
        type: list
      site:
        description: Full Site Hierarchy where device has to be assigned.
        type: str
    type: list
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Wireless Provision
    description: Complete reference of the Provision API.
    link: https://developer.cisco.com/docs/dna-center/#!provision
notes:
  - SDK Method used are
    wireless.Wireless.provision,
  - Paths used are
    post /dna/intent/api/v1/wireless/provision,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.wireless_provision_device_create:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: '{{my_headers | from_json}}'
    payload:
      - deviceName: string
        dynamicInterfaces:
          - interfaceGateway: string
            interfaceIPAddress: string
            interfaceName: string
            interfaceNetmaskInCIDR: 0
            lagOrPortNumber: 0
            vlanId: 0
        managedAPLocations:
          - string
        site: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "executionId": "string",
      "executionStatusUrl": "string",
      "message": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: sda_transit_networks
short_description: Resource module for Sda Transit Networks
description:
  - Manage operations create and update of the resource Sda Transit Networks.
  - Adds transit networks based on user input.
  - Updates transit networks based on user input.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  payload:
    description: Sda Transit Networks's payload.
    elements: dict
    suboptions:
      ipTransitSettings:
        description: Sda Transit Networks's ipTransitSettings.
        suboptions:
          autonomousSystemNumber:
            description: Autonomous System Number of the IP transit network. Allowed range is 1 to 4294967295 (updating this
              field is not allowed).
            type: str
          routingProtocolName:
            description: Routing Protocol Name of the IP transit network (updating this field is not allowed).
            type: str
        type: dict
      name:
        description: Name of the transit network.
        type: str
      sdaTransitSettings:
        description: Sda Transit Networks's sdaTransitSettings.
        suboptions:
          controlPlaneNetworkDeviceIds:
            description: List of network device IDs that will be used as control plane nodes. Maximum 2 network device IDs
              can be provided for transit of type SDA_LISP_BGP_TRANSIT and maximum 4 network device IDs can be provided for
              transit of type SDA_LISP_PUB_SUB_TRANSIT.
            elements: str
            type: list
          isMulticastOverTransitEnabled:
            description: Set this to true to enable multicast over SD-Access transit. This supports Native Multicast over
              SD-Access Transit. This is only applicable for transit of type SDA_LISP_PUB_SUB_TRANSIT.
            type: bool
        type: dict
      siteId:
        description: ID of the site of this transit network. The transit network will be anchored at this Site. Only Fabric
          Sites within this Site location can associate their borders with this transit network. Additionally, the Transit
          Control Plane Devices must be located within the transit network's Site.
        type: str
      type:
        description: Type of the transit network.
        type: str
    type: list
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for SDA AddTransitNetworks
    description: Complete reference of the AddTransitNetworks API.
    link: https://developer.cisco.com/docs/dna-center/#!add-transit-networks
  - name: Cisco DNA Center documentation for SDA UpdateTransitNetworks
    description: Complete reference of the UpdateTransitNetworks API.
    link: https://developer.cisco.com/docs/dna-center/#!update-transit-networks
notes:
  - SDK Method used are
    sda.Sda.add_transit_networks,
    sda.Sda.update_transit_networks,
  - Paths used are
    post /dna/intent/api/v1/sda/transitNetworks,
    put /dna/intent/api/v1/sda/transitNetworks,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.sda_transit_networks:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    payload:
      - ipTransitSettings:
          autonomousSystemNumber: string
          routingProtocolName: string
        name: string
        sdaTransitSettings:
          controlPlaneNetworkDeviceIds:
            - string
          isMulticastOverTransitEnabled: true
        siteId: string
        type: string
- name: Update all
  cisco.dnac.sda_transit_networks:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    payload:
      - id: string
        ipTransitSettings:
          autonomousSystemNumber: string
          routingProtocolName: string
        name: string
        sdaTransitSettings:
          controlPlaneNetworkDeviceIds:
            - string
          isMulticastOverTransitEnabled: true
        siteId: string
        type: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: energy_network_devices_info
short_description: Information module for Energy Network Devices
description:
  - Get all Energy Network Devices.
  - Get Energy Network Devices by id.
  - Retrieves a list of network devices with energy data based on the specified query parameters.
  - For detailed information about the usage of the API, please refer to the Open API specification document
    https //github.com/cisco-en-programmability/catalyst-center-api-specs/blob/main/Assurance/
    CE_Cat_Center_Org-deviceEnergy_1.0-1.0.1-resolved.yaml.
  - Retrieves network device energy data for a specified time range based on the device ID.
  - For detailed information about the usage of the API, please refer to the Open API specification document
    https //github.com/cisco-en-programmability/catalyst-center-api-specs/blob/main/Assurance/
    CE_Cat_Center_Org-deviceEnergy_1.0-1.0.1-resolved.yaml.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  startTime:
    description:
      - >
        StartTime query parameter. Start time from which API queries the data set related to the resource. It
        must be specified in UNIX epochtime in milliseconds. Value is inclusive. If `startTime` is not provided,
        API will default to one day before `endTime`.
    type: float
  endTime:
    description:
      - >
        EndTime query parameter. End time to which API queries the data set related to the resource. It must be
        specified in UNIX epochtime in milliseconds. Value is inclusive. If `endTime` is not provided, API will
        default to one day after `startTime`. If `startTime` is not provided either, API will default to current
        time.
    type: float
  limit:
    description:
      - Limit query parameter. Maximum number of records to return.
    type: int
  cursor:
    description:
      - >
        Cursor query parameter. It's an opaque string field that indicates the next record in the requested
        collection. If no records remain, the API returns a response with a count of zero. The default value is
        an empty string, and the initial value must be an empty string. The cursor value is populated by the API
        in the response page block. If the user wants more records, the cursor in the subsequent request must be
        updated with the value from the previous response.
    type: str
  sortBy:
    description:
      - SortBy query parameter. A field within the response to sort by.
    type: str
  order:
    description:
      - Order query parameter. The sort order of the field ascending or descending.
    type: str
  id:
    description:
      - >
        Id query parameter. The list of Device Uuids (e.g., `6bef213c-19ca-4170-8375-b694e251101c`). Examples
        `id=6bef213c-19ca-4170-8375-b694e251101c` (single device requested)
        `id=6bef213c-19ca-4170-8375-b694e251101c&id=32219612-819e-4b5e-a96b-cf22aca13dd9`.
    type: str
  siteId:
    description:
      - >
        SiteId query parameter. The UUID of the site. (Ex. `flooruuid`) Examples `?siteId=id1` (single id
        requested) `?siteId=id1&siteId=id2&siteId=id3` (multiple ids requested).
    type: str
  siteHierarchy:
    description:
      - >
        SiteHierarchy query parameter. The full hierarchical breakdown of the site tree starting from Global
        site name and ending with the specific site name. The Root site is named "Global" (Ex.
        `Global/AreaName/BuildingName/FloorName`) This field supports wildcard asterisk (`*`) character search
        support. E.g. `*/San*, */San, /San*` Examples `?siteHierarchy=Global/AreaName/BuildingName/FloorName`
        (single siteHierarchy requested) `?siteHierarchy=Global/AreaName/BuildingName/FloorName&siteHierarchy=Gl
        obal/AreaName2/BuildingName2/FloorName2` (multiple siteHierarchies requested).
    type: str
  siteHierarchyId:
    description:
      - >
        SiteHierarchyId query parameter. The full hierarchy breakdown of the site tree in id form starting from
        Global site UUID and ending with the specific site UUID. (Ex.
        `globalUuid/areaUuid/buildingUuid/floorUuid`) This field supports wildcard asterisk (`*`) character
        search support. E.g. `*uuid*, *uuid, uuid*` Examples
        `?siteHierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid `(single siteHierarchyId requested) `?siteH
        ierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid&siteHierarchyId=globalUuid/areaUuid2/buildingUuid2
        /floorUuid2` (multiple siteHierarchyIds requested).
    type: str
  deviceCategory:
    description:
      - >
        DeviceCategory query parameter. The list of device deviceCategories. Examples `deviceCategory=Switch`
        (single device family requested) `deviceCategory=Switch&deviceCategory=Router` (multiple device
        categories with comma separator).
    type: str
  deviceSubCategory:
    description:
      - >
        DeviceSubCategory query parameter. The list of device sub categories. Examples `deviceSubCategory=Cisco
        Catalyst 9300 Series Switches` (single device family requested) `deviceSubCategory=Cisco Catalyst 9300
        Series Switches&deviceSubCategory=Cisco Catalyst 9400 Series Switches`.
    type: str
  view:
    description:
      - >
        View query parameter. List of views. View and attribute work in union. Each view will include its
        attributes. For example, view device includes all the attributes related to device. Please refer to
        `NetworkDeviceEnergyView` model for supported list of views Examples `view=device&view=energy`.
    type: str
  attribute:
    description:
      - >
        Attribute query parameter. List of attributes. Please refer to `NetworkDeviceEnergyAttribute` for
        supported list of attributes Examples `attribute=id&attribute=energyConsumed`.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Devices GetDeviceEnergyByID
    description: Complete reference of the GetDeviceEnergyByID API.
    link: https://developer.cisco.com/docs/dna-center/#!get-device-energy-by-id
  - name: Cisco DNA Center documentation for Devices GetDevicesEnergy
    description: Complete reference of the GetDevicesEnergy API.
    link: https://developer.cisco.com/docs/dna-center/#!get-devices-energy
notes:
  - SDK Method used are
    devices.Devices.get_device_energy_by_id,
    devices.Devices.get_devices_energy,
  - Paths used are
    get /dna/data/api/v1/energy/networkDevices,
    get /dna/data/api/v1/energy/networkDevices/{id},
"""

EXAMPLES = r"""
---
- name: Get all Energy Network Devices
  cisco.dnac.energy_network_devices_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    startTime: 0
    endTime: 0
    limit: 0
    cursor: string
    sortBy: string
    order: string
    id: string
    siteId: string
    siteHierarchy: string
    siteHierarchyId: string
    deviceCategory: string
    deviceSubCategory: string
    view: string
    attribute: string
  register: result
- name: Get Energy Network Devices by id
  cisco.dnac.energy_network_devices_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    startTime: 0
    endTime: 0
    view: string
    attribute: string
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "id": "string",
        "deviceName": "string",
        "deviceCategory": "string",
        "deviceSubCategory": "string",
        "siteId": "string",
        "siteHierarchy": "string",
        "siteHierarchyId": "string",
        "energyConsumed": 0,
        "estimatedCost": 0,
        "estimatedEmission": 0,
        "carbonIntensity": 0
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: images_distribution_server_settings_info
short_description: Information module for Images Distribution Server Settings
description:
  - Get all Images Distribution Server Settings.
  - Get Images Distribution Server Settings by id.
  - Retrieve image distribution server for the given server identifier. - > Retrieve the list of remote image distribution
    servers. There can be up to two remote servers.Product always acts as local distribution server, and it is not part of
    this API response.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - Id path parameter. Server identifier.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Software Image Management (SWIM) RetrieveImageDistributionServers
    description: Complete reference of the RetrieveImageDistributionServers API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieve-image-distribution-servers
  - name: Cisco DNA Center documentation for Software Image Management (SWIM) RetrieveSpecificImageDistributionServer
    description: Complete reference of the RetrieveSpecificImageDistributionServer API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieve-specific-image-distribution-server
notes:
  - SDK Method used are
    software_image_management_swim.SoftwareImageManagementSwim.retrieve_image_distribution_servers,
    software_image_management_swim.SoftwareImageManagementSwim.retrieve_specific_image_distribution_server,
  - Paths used are
    get /dna/intent/api/v1/images/distributionServerSettings,
    get /dna/intent/api/v1/images/distributionServerSettings/{id},
"""

EXAMPLES = r"""
---
- name: Get all Images Distribution Server Settings
  cisco.dnac.images_distribution_server_settings_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
  register: result
- name: Get Images Distribution Server Settings by id
  cisco.dnac.images_distribution_server_settings_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "username": "string",
          "serverAddress": "string",
          "portNumber": 0,
          "rootLocation": "string"
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: assurance_issues_ignore
short_description: Resource module for Assurance Issues Ignore
description:
  - Manage operation create of the resource Assurance Issues Ignore.
  - Ignores the given list of issues. The response contains the list of issues which were successfully ignored
    as well as the issues which are failed to ignore.
  - After this API returns success response, it may take few seconds for the issue status to be updated
    if the system is heavily loaded.
  - Please use `GET /dna/data/api/v1/assuranceIssues/{id}` API to fetch the details of a particular issue
    and verify `updatedTime`.
  - For detailed information about the usage of the API, please refer to the Open API specification document
    https //github.com/cisco-en-programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-IssuesLifecycle-1.0.0-resolved.yaml.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  ignoreHours:
    description: Ignore Hours.
    type: int
  issueIds:
    description: Issue Ids.
    elements: str
    type: list
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Issues IgnoreTheGivenListOfIssues
    description: Complete reference of the IgnoreTheGivenListOfIssues API.
    link: https://developer.cisco.com/docs/dna-center/#!ignore-the-given-list-of-issues
notes:
  - SDK Method used are
    issues.Issues.ignore_the_given_list_of_issues,
  - Paths used are
    post /dna/intent/api/v1/assuranceIssues/ignore,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.assurance_issues_ignore:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: '{{my_headers | from_json}}'
    ignoreHours: 0
    issueIds:
      - string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "successfulIssueIds": [
          "string"
        ],
        "failureIssueIds": [
          "string"
        ]
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: iot_network_devices_network_device_id_mrp_rings_count_info
short_description: Information module for Iot Network Devices  Network Device Id Mrp Rings Count
description:
  - Get all Iot Network Devices  Network Device Id Mrp Rings Count. - > This API returns the count of MRP rings for the given
    fields - networkDeviceId Network device ID of the MRP ring member. The networkDeviceId is the instanceUuid attribute in
    the response of API - /dna/intent/api/v1/networkDevices .
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  networkDeviceId:
    description:
      - NetworkDeviceId path parameter. Network device ID of the MRP ring member.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Industrial Configuration RetrievesTheCountOfMRPRings
    description: Complete reference of the RetrievesTheCountOfMRPRings API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieves-the-count-of-mrp-rings
notes:
  - SDK Method used are
    industrial_configuration.IndustrialConfiguration.retrieves_the_count_of_m_r_p_rings,
  - Paths used are
    get /dna/intent/api/v1/iot/networkDevices/{networkDeviceId}/mrpRings/count,
"""

EXAMPLES = r"""
---
- name: Get all Iot Network Devices  Network Device Id Mrp Rings Count
  cisco.dnac.iot_network_devices_network_device_id_mrp_rings_count_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    networkDeviceId: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: list
  elements: dict
  sample: >
    [
      {
        "response": [
          {
            "count": 0
          }
        ],
        "version": 0
      }
    ]
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: update_wired_network_devices_id_config_features_intended_layer2
short_description: Resource module for Update Wired Network Devices Id Config Features Intended Layer2
description:
  - Manage operation update of the resource Update Wired Network Devices Id Config Features Intended Layer2. - > This API
    updates the configurations for the intended features on a wired device. Only the feature configurations to be changed
    need to be added to the intended features. Updates to intended features can be done over several iterations. Once the
    updates are complete, the intended features can be deployed to a device using the API /dna/intent/api/v1/networkDevices/{id}/configFeatures/intended/deploy.
    When the intended features are deployed, they are applied on top of the existing configurations on the device. Any existing
    configurations on the device which are not included in the intended features, are retained on the device.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  id:
    description: Id path parameter. Network device ID of the wired device to configure.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Wired UpdateConfigurationsForIntendedLayer2FeaturesOnAWiredDevice
    description: Complete reference of the UpdateConfigurationsForIntendedLayer2FeaturesOnAWiredDevice API.
    link: https://developer.cisco.com/docs/dna-center/#!update-configurations-for-intended-layer-2-features-on-a-wired-device
notes:
  - SDK Method used are
    wired.Wired.update_configurations_for_intended_layer2_features_on_a_wired_device,
  - Paths used are
    put /dna/intent/api/v1/wired/networkDevices/{id}/configFeatures/intended/layer2,
"""

EXAMPLES = r"""
---
- name: Update all
  cisco.dnac.update_wired_network_devices_id_config_features_intended_layer2:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    id: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: task_count_info
short_description: Information module for Task Count
description:
  - Get all Task Count.
  - Returns Task count.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  startTime:
    description:
      - StartTime query parameter. This is the epoch start time from which tasks need to be fetched.
    type: str
  endTime:
    description:
      - EndTime query parameter. This is the epoch end time upto which audit records need to be fetched.
    type: str
  data:
    description:
      - Data query parameter. Fetch tasks that contains this data.
    type: str
  errorCode:
    description:
      - ErrorCode query parameter. Fetch tasks that have this error code.
    type: str
  serviceType:
    description:
      - ServiceType query parameter. Fetch tasks with this service type.
    type: str
  username:
    description:
      - Username query parameter. Fetch tasks with this username.
    type: str
  progress:
    description:
      - Progress query parameter. Fetch tasks that contains this progress.
    type: str
  isError:
    description:
      - IsError query parameter. Fetch tasks ended as success or failure. Valid values true, false.
    type: str
  failureReason:
    description:
      - FailureReason query parameter. Fetch tasks that contains this failure reason.
    type: str
  parentId:
    description:
      - ParentId query parameter. Fetch tasks that have this parent Id.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Task GetTaskCount
    description: Complete reference of the GetTaskCount API.
    link: https://developer.cisco.com/docs/dna-center/#!get-task-count
notes:
  - SDK Method used are
    task.Task.get_task_count,
  - Paths used are
    get /dna/intent/api/v1/task/count,
"""

EXAMPLES = r"""
---
- name: Get all Task Count
  cisco.dnac.task_count_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    startTime: string
    endTime: string
    data: string
    errorCode: string
    serviceType: string
    username: string
    progress: string
    isError: string
    failureReason: string
    parentId: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": 0,
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: compliance_policys_sites_rules_variables_info
short_description: Information module for Compliance Policys Sites Rules Variables
description:
  - Get all Compliance Policys Sites Rules Variables.
  - Retrieve the site variables for the specified rule within the compliance policy.
version_added: '6.46.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  policyId:
    description:
      - PolicyId path parameter. The `id` of the compliance policy.
    type: str
  siteId:
    description:
      - SiteId path parameter. The `id` of the site to which compliance policy is associated.
    type: str
  ruleId:
    description:
      - RuleId path parameter. The `id` of the rule within the compliance policy.
    type: str
  _inherited:
    description:
      - >
        _inherited query parameter. Include values explicitly set for this site; when false, null values
        indicate that the site inherits these values from the parent site or a higher level in the site
        hierarchy.
    type: bool
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Compliance RetrieveSiteVariables
    description: Complete reference of the RetrieveSiteVariables API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieve-site-variables
notes:
  - SDK Method used are
    compliance.Compliance.retrieve_site_variables,
  - Paths used are
    get /dna/intent/api/v1/compliancePolicys/{policyId}/sites/{siteId}/rules/{ruleId}/variables,
"""

EXAMPLES = r"""
---
- name: Get all Compliance Policys Sites Rules Variables
  cisco.dnac.compliance_policys_sites_rules_variables_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    _inherited: true
    policyId: string
    siteId: string
    ruleId: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "variableValues": [
          {
            "id": "string",
            "values": [
              "string"
            ]
          }
        ],
        "inheritedSiteId": "string",
        "inheritedSiteName": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: create_wired_network_devices_id_config_features_intended_layer2
short_description: Resource module for Create Wired Network Devices Id Config Features Intended Layer2
description:
  - Manage operation create of the resource Create Wired Network Devices Id Config Features Intended Layer2. - > This API
    creates configurations for the intended features on a wired device, if none have been added earlier. Only the feature
    configurations to be changed need to be added to the intended features. When the intended features are deployed to a device
    using the API /intent/api/v1/networkDevices/{id}/configFeatures/intended/deploy, they are applied on top of the existing
    configurations on the device. Any existing configurations on the device which are not included in the intended features,
    are retained on the device.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  id:
    description: Id path parameter. Network device ID of the wired device to configure.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Wired CreateConfigurationsForIntendedLayer2FeaturesOnAWiredDevice
    description: Complete reference of the CreateConfigurationsForIntendedLayer2FeaturesOnAWiredDevice API.
    link: https://developer.cisco.com/docs/dna-center/#!create-configurations-for-intended-layer-2-features-on-a-wired-device
notes:
  - SDK Method used are
    wired.Wired.create_configurations_for_intended_layer2_features_on_a_wired_device,
  - Paths used are
    post /dna/intent/api/v1/wired/networkDevices/{id}/configFeatures/intended/layer2,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.create_wired_network_devices_id_config_features_intended_layer2:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    id: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: energy_sites_query_count
short_description: Resource module for Energy Sites Query Count
description:
  - Manage operation create of the resource Energy Sites Query Count. - > Submits a request to retrieve the total count of
    sites that provide energy data, filtered according to the specified query parameters. For detailed information about the
    usage of the API, please refer to the Open API specification document - https //github.com/cisco-en-programmability/catalyst-center-api-
    specs/blob/main/Assurance/CE_Cat_Center_Org-sitesEnergy-1.0.1-resolved.yaml.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  aggregateAttributes:
    description: Energy Sites Query Count's aggregateAttributes.
    elements: dict
    suboptions:
      function:
        description: Function.
        type: str
      name:
        description: Name.
        type: str
    type: list
  attributes:
    description: Attributes.
    elements: str
    type: list
  endTime:
    description: End Time.
    type: int
  filters:
    description: Energy Sites Query Count's filters.
    elements: dict
    suboptions:
      filters:
        description: Energy Sites Query Count's filters.
        elements: dict
        suboptions:
          key:
            description: Key.
            type: str
          operator:
            description: Operator.
            type: str
          value:
            description: Value.
            elements: str
            type: list
        type: list
      logicalOperator:
        description: Logical Operator.
        type: str
    type: list
  headers:
    description: Additional headers.
    type: dict
  page:
    description: Energy Sites Query Count's page.
    suboptions:
      limit:
        description: Limit.
        type: int
      offset:
        description: Offset.
        type: int
      sortBy:
        description: Energy Sites Query Count's sortBy.
        elements: dict
        suboptions:
          function:
            description: Function.
            type: str
          name:
            description: Name.
            type: str
          order:
            description: Order.
            type: str
        type: list
    type: dict
  startTime:
    description: Start Time.
    type: int
  taskId:
    description: TaskId query parameter. Used to retrieve asynchronously processed & stored data. When this parameter is used,
      the rest of the request params will be ignored.
    type: str
  views:
    description: Views.
    elements: str
    type: list
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Sites SubmitRequestToCountSitesEnergyFromQuery
    description: Complete reference of the SubmitRequestToCountSitesEnergyFromQuery API.
    link: https://developer.cisco.com/docs/dna-center/#!submit-request-to-count-sites-energy-from-query
notes:
  - SDK Method used are
    sites.Sites.submit_request_to_count_sites_energy_from_query,
  - Paths used are
    post /dna/data/api/v1/energy/sites/query/count,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.energy_sites_query_count:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    aggregateAttributes:
      - function: string
        name: string
    attributes:
      - string
    endTime: 0
    filters:
      - filters:
          - key: string
            operator: string
            value:
              - string
        logicalOperator: string
    headers: '{{my_headers | from_json}}'
    page:
      limit: 0
      offset: 0
      sortBy:
        - function: string
          name: string
          order: string
    startTime: 0
    taskId: string
    views:
      - string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "count": 0
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: security_rogue_wireless_containment_stop
short_description: Resource module for Security Rogue Wireless-Containment Stop
description:
  - Manage operation create of the resource Security Rogue Wireless-Containment Stop. - > Intent API to stop the wireless
    rogue access point containment. This API will stop the containment through single WLC. The response includes the details
    like WLC and BSSID on which the stop containment has been initiated.
version_added: '6.16.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  macAddress:
    description: Mac Address.
    type: str
  type:
    description: Type.
    type: int
  wlcIp:
    description: Wlc Ip.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Devices StopWirelessRogueAPContainment
    description: Complete reference of the StopWirelessRogueAPContainment API.
    link: https://developer.cisco.com/docs/dna-center/#!stop-wireless-rogue-ap-containment
notes:
  - SDK Method used are
    devices.Devices.stop_wireless_rogue_ap_containment,
  - Paths used are
    post /dna/intent/api/v1/security/rogue/wireless-containment/stop,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.security_rogue_wireless_containment_stop:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    macAddress: string
    type: 0
    wlcIp: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "macAddress": "string",
        "type": 0,
        "initiatedOnWlcIp": "string",
        "taskId": "string",
        "taskType": "string",
        "initiatedOnBssid": [
          "string"
        ]
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: filter_groups_info
short_description: Information module for Filter Groups
description:
  - Get all Filter Groups.
  - Get Filter Groups by id. - > Returns the details of filter group for the given id. For detailed information about the
    usage of the API, please refer to the Open API specification document - https //github.com/cisco-en-programmability/catalyst-
    center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-FilterGroups-1.0.0-resolved.yaml. - > Returns the details of filter
    groups for given search criteria specified in query parameters. For detailed information about the usage of the API, please
    refer to the Open API specification document - https //github.com/cisco-en-programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-
    FilterGroups-1.0.0-resolved.yaml.
version_added: '6.46.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - >
        Id query parameter. Filter Group id. Examples `?id=2ee1b9f0-8036-443b-bad0-7692760af1b5`(single id
        requested) `?id=2ee1b9f0-8036-443b-bad0-7692760af1b5&id=ae368f0b-f4e3-4e8f-a914-011cbd19bb51` (multiple
        ids requested).
    type: str
  name:
    description:
      - >
        Name query parameter. Filter Group name. Examples `?name=SJC Wireless`(single name requested) `?name=SJC
        Wireless&name=Global Wired` (multiple names requested).
    type: str
  type:
    description:
      - >
        Type query parameter. Type of the filter group. Examples type=Generic (single Filter Group type
        requested) type=Generic&type=Site (multiple Filter Group types requested).
    type: str
  offset:
    description:
      - >
        Offset query parameter. Specifies the starting point within all records returned by the API. It's one
        based offset. The starting value is 1.
    type: int
  limit:
    description:
      - Limit query parameter. Maximum number of records to return.
    type: int
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Devices GetTheFilterGroupDetailsForTheGivenId
    description: Complete reference of the GetTheFilterGroupDetailsForTheGivenId API.
    link: https://developer.cisco.com/docs/dna-center/#!get-the-filter-group-details-for-the-given-id
  - name: Cisco DNA Center documentation for Devices GetTheFilterGroupsForGivenSearchCriteria
    description: Complete reference of the GetTheFilterGroupsForGivenSearchCriteria API.
    link: https://developer.cisco.com/docs/dna-center/#!get-the-filter-groups-for-given-search-criteria
notes:
  - SDK Method used are
    devices.Devices.get_the_filter_group_details_for_the_given_id,
    devices.Devices.get_the_filter_groups_for_given_search_criteria,
  - Paths used are
    get /dna/intent/api/v1/filterGroups,
    get /dna/intent/api/v1/filterGroups/{id},
"""

EXAMPLES = r"""
---
- name: Get all Filter Groups
  cisco.dnac.filter_groups_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
    name: string
    type: string
    offset: 0
    limit: 0
  register: result
- name: Get Filter Groups by id
  cisco.dnac.filter_groups_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "id": "string",
        "name": "string",
        "type": "string",
        "filters": [
          {
            "key": "string",
            "operator": "string",
            "value": "string",
            "displayValue": "string"
          }
        ]
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wireless_profiles_id_policy_tags_policy_tag_id
short_description: Resource module for Wireless Profiles Id Policy Tags Policy Tag Id
description:
  - Manage operations update and delete of the resource Wireless Profiles Id Policy Tags Policy Tag Id. - > This endpoint
    allows for the deletion of a specific `Policy Tag` associated with a given `Wireless Profile`. This API requires the `id`
    of the `Wireless Profile` and the `policyTagId` of the `Policy Tag` to be provided as path parameters. - > This endpoint
    allows updating the details of a specific `Policy Tag` associated with a given `Wireless Profile`. The `id` of the `Wireless
    Profile` and the `policyTagId` of the Policy Tag must be provided as path parameters, and the request body should contain
    the updated details of the `Policy Tag`. The `policyTagName` cannot be modified through this endpoint.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  apZones:
    description: Ap Zones.
    elements: str
    type: list
  id:
    description: Id path parameter. Wireless Profile Id.
    type: str
  policyTagId:
    description: PolicyTagId path parameter. Policy Tag Id.
    type: str
  policyTagName:
    description: Policy Tag Name.
    type: str
  siteIds:
    description: Site Ids.
    elements: str
    type: list
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Wireless DeleteASpecificPolicyTagFromAWirelessProfile
    description: Complete reference of the DeleteASpecificPolicyTagFromAWirelessProfile API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-a-specific-policy-tag-from-a-wireless-profile
  - name: Cisco DNA Center documentation for Wireless UpdateASpecificPolicyTagForAWirelessProfile
    description: Complete reference of the UpdateASpecificPolicyTagForAWirelessProfile API.
    link: https://developer.cisco.com/docs/dna-center/#!update-a-specific-policy-tag-for-a-wireless-profile
notes:
  - SDK Method used are
    wireless.Wireless.delete_a_specific_policy_tag_from_a_wireless_profile,
    wireless.Wireless.update_a_specific_policy_tag_for_a_wireless_profile,
  - Paths used are
    delete /dna/intent/api/v1/wirelessProfiles/{id}/policyTags/{policyTagId},
    put /dna/intent/api/v1/wirelessProfiles/{id}/policyTags/{policyTagId},
"""

EXAMPLES = r"""
---
- name: Delete by id
  cisco.dnac.wireless_profiles_id_policy_tags_policy_tag_id:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    id: string
    policyTagId: string
- name: Update by id
  cisco.dnac.wireless_profiles_id_policy_tags_policy_tag_id:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    apZones:
      - string
    id: string
    policyTagId: string
    policyTagName: string
    siteIds:
      - string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: assurance_issues_update
short_description: Resource module for Assurance Issues Update
description:
  - Manage operation create of the resource Assurance Issues Update. - > Updates selected fields in the given issue. Currently
    the only field that can be updated is 'notes' field. After this API returns success response, it may take few seconds
    for the issue details to be updated if the system is heavily loaded. Please use `GET /dna/data/api/v1/assuranceIssues/{id}`
    API to fetch the details of a particular issue and verify `updatedTime`. For detailed information about the usage of the
    API, please refer to the Open API specification document - https //github.com/cisco-en-programmability/catalyst-center-api-
    specs/blob/main/Assurance/CE_Cat_Center_Org-IssuesLifecycle-1.0.0-resolved.yaml.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description: Id path parameter. The issue Uuid.
    type: str
  notes:
    description: Notes.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Issues UpdateTheGivenIssueByUpdatingSelectedFields
    description: Complete reference of the UpdateTheGivenIssueByUpdatingSelectedFields API.
    link: https://developer.cisco.com/docs/dna-center/#!update-the-given-issue-by-updating-selected-fields
notes:
  - SDK Method used are
    issues.Issues.update_the_given_issue_by_updating_selected_fields,
  - Paths used are
    post /dna/intent/api/v1/assuranceIssues/{id}/update,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.assurance_issues_update:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: '{{my_headers | from_json}}'
    id: string
    notes: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "issueId": "string",
        "name": "string",
        "description": "string",
        "summary": "string",
        "priority": "string",
        "severity": "string",
        "deviceType": "string",
        "category": "string",
        "entityType": "string",
        "entityId": "string",
        "firstOccurredTime": 0,
        "mostRecentOccurredTime": 0,
        "status": "string",
        "isGlobal": true,
        "updatedBy": "string",
        "updatedTime": 0,
        "notes": "string",
        "siteId": "string",
        "siteHierarchyId": "string",
        "siteName": "string",
        "siteHierarchy": "string",
        "suggestedActions": [
          {
            "message": "string"
          }
        ],
        "additionalAttributes": [
          {
            "key": "string",
            "value": "string"
          }
        ]
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: task_tree_info
short_description: Information module for Task Tree
description:
  - Get all Task Tree.
  - Returns a task with its children tasks by based on their id.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  taskId:
    description:
      - TaskId path parameter. UUID of the Task.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Task GetTaskTree
    description: Complete reference of the GetTaskTree API.
    link: https://developer.cisco.com/docs/dna-center/#!get-task-tree
notes:
  - SDK Method used are
    task.Task.get_task_tree,
  - Paths used are
    get /dna/intent/api/v1/task/{taskId}/tree,
"""

EXAMPLES = r"""
---
- name: Get all Task Tree
  cisco.dnac.task_tree_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    taskId: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "additionalStatusURL": "string",
          "data": "string",
          "endTime": 0,
          "errorCode": "string",
          "errorKey": "string",
          "failureReason": "string",
          "id": "string",
          "instanceTenantId": "string",
          "isError": true,
          "lastUpdate": 0,
          "operationIdList": {},
          "parentId": "string",
          "progress": "string",
          "rootId": "string",
          "serviceType": "string",
          "startTime": 0,
          "username": "string",
          "version": 0
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wireless_accesspoint_configuration_count_info
short_description: Information module for Wireless Accesspoint Configuration Count
description:
  - Get all Wireless Accesspoint Configuration Count.
  - Get Access Point Configuration Count.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  wlcIpAddress:
    description:
      - WlcIpAddress query parameter. WLC IP Address.
    type: str
  apMode:
    description:
      - >
        ApMode query parameter. AP Mode. Allowed values are Local, Bridge, Monitor, FlexConnect, Sniffer, Rogue
        Detector, SE-Connect, Flex+Bridge, Sensor.
    type: str
  apModel:
    description:
      - ApModel query parameter. AP Model.
    type: str
  meshRole:
    description:
      - MeshRole query parameter. Mesh Role. Allowed values are RAP or MAP.
    type: str
  provisioned:
    description:
      - Provisioned query parameter. Indicate whether AP provisioned or not. Allowed values are True or False.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Wireless GetAccessPointConfigurationCount
    description: Complete reference of the GetAccessPointConfigurationCount API.
    link: https://developer.cisco.com/docs/dna-center/#!get-access-point-configuration-count
notes:
  - SDK Method used are
    wireless.Wireless.get_access_point_configuration_count,
  - Paths used are
    get /dna/intent/api/v1/wireless/accesspoint-configuration/count,
"""

EXAMPLES = r"""
---
- name: Get all Wireless Accesspoint Configuration Count
  cisco.dnac.wireless_accesspoint_configuration_count_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    wlcIpAddress: string
    apMode: string
    apModel: string
    meshRole: string
    provisioned: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "count": 0
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: filter_group_associations
short_description: Resource module for Filter Group Associations
description:
  - Manage operation create of the resource Filter Group Associations. - > Creates association between a filter group and
    entity. For detailed information about the usage of the API, please refer to the Open API specification document - https
    //github.com/cisco-en-programmability/catalyst- center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-FilterGroups-1.0.0-resolved.yaml.
version_added: '6.46.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  entityId:
    description: Entity Id.
    type: str
  entityName:
    description: Entity Name.
    type: str
  entityType:
    description: Entity Type.
    type: str
  filterGroupId:
    description: Filter Group Id.
    type: str
  headers:
    description: Additional headers.
    type: dict
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Devices CreateFilterGroupAssociation
    description: Complete reference of the CreateFilterGroupAssociation API.
    link: https://developer.cisco.com/docs/dna-center/#!create-filter-group-association
notes:
  - SDK Method used are
    devices.Devices.create_filter_group_association,
  - Paths used are
    post /dna/intent/api/v1/filterGroupAssociations,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.filter_group_associations:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    entityId: string
    entityName: string
    entityType: string
    filterGroupId: string
    headers: '{{my_headers | from_json}}'
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "id": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: clients_query
short_description: Resource module for Clients Query
description:
  - Manage operation create of the resource Clients Query. - > Retrieves the list of clients by applying complex filters while
    also supporting aggregate attributes. For detailed information about the usage of the API, please refer to the Open API
    specification document - https //github.com/cisco-en-programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-
    clients1-1.0.0-resolved.yaml.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  aggregateAttributes:
    description: Clients Query's aggregateAttributes.
    elements: dict
    suboptions:
      function:
        description: Function.
        type: str
      name:
        description: Name.
        type: str
    type: list
  attributes:
    description: Attributes.
    elements: str
    type: list
  endTime:
    description: End Time.
    type: int
  filters:
    description: Clients Query's filters.
    elements: dict
    suboptions:
      key:
        description: Key.
        type: str
      operator:
        description: Operator.
        type: str
      value:
        description: Value.
        type: int
    type: list
  headers:
    description: Additional headers.
    type: dict
  page:
    description: Clients Query's page.
    suboptions:
      limit:
        description: Limit.
        type: int
      offset:
        description: Offset.
        type: int
      sortBy:
        description: Clients Query's sortBy.
        elements: dict
        suboptions:
          name:
            description: Name.
            type: str
          order:
            description: Order.
            type: str
        type: list
    type: dict
  startTime:
    description: Start Time.
    type: int
  views:
    description: Views.
    elements: str
    type: list
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Clients RetrievesTheListOfClientsByApplyingComplexFiltersWhileAlsoSupportingAggregateAttributes
    description: Complete reference of the RetrievesTheListOfClientsByApplyingComplexFiltersWhileAlsoSupportingAggregateAttributes
      API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieves-the-list-of-clients-by-applying-complex-filters-while-also-supporting-aggregate-attributes
notes:
  - SDK Method used are
    clients.Clients.retrieves_the_list_of_clients_by_applying_complex_filters_while_also_supporting_aggregate_attributes,
  - Paths used are
    post /dna/data/api/v1/clients/query,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.clients_query:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    aggregateAttributes:
      - function: string
        name: string
    attributes:
      - string
    endTime: 0
    filters:
      - key: string
        operator: string
        value: 0
    headers: '{{my_headers | from_json}}'
    page:
      limit: 0
      offset: 0
      sortBy:
        - name: string
          order: string
    startTime: 0
    views:
      - string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "macAddress": "string",
          "type": "string",
          "name": "string",
          "userId": "string",
          "username": "string",
          "ipv4Address": "string",
          "ipv6Addresses": [
            "string"
          ],
          "vendor": "string",
          "osType": "string",
          "osVersion": "string",
          "formFactor": "string",
          "siteHierarchy": "string",
          "siteHierarchyId": "string",
          "siteId": "string",
          "lastUpdatedTime": 0,
          "connectionStatus": "string",
          "tracked": "string",
          "isPrivateMacAddress": true,
          "health": {
            "overallScore": 0,
            "onboardingScore": 0,
            "connectedScore": 0,
            "linkErrorPercentageThreshold": 0,
            "isLinkErrorIncluded": true,
            "rssiThreshold": 0,
            "snrThreshold": 0,
            "isRssiIncluded": true,
            "isSnrIncluded": true
          },
          "traffic": {
            "txBytes": 0,
            "rxBytes": 0,
            "usage": 0,
            "rxPackets": 0,
            "txPackets": 0,
            "rxRate": 0,
            "txRate": 0,
            "rxLinkErrorPercentage": 0,
            "txLinkErrorPercentage": 0,
            "rxRetries": 0,
            "rxRetryPercentage": 0,
            "txDrops": 0,
            "txDropPercentage": 0,
            "dnsRequestCount": 0,
            "dnsResponseCount": 0
          },
          "connectedNetworkDevice": {
            "connectedNetworkDeviceId": "string",
            "connectedNetworkDeviceName": "string",
            "connectedNetworkDeviceManagementIp": "string",
            "connectedNetworkDeviceMac": "string",
            "connectedNetworkDeviceType": "string",
            "interfaceName": "string",
            "interfaceSpeed": 0,
            "duplexMode": "string"
          },
          "connection": {
            "vlanId": "string",
            "sessionDuration": 0,
            "vnId": "string",
            "l2Vn": "string",
            "l3Vn": "string",
            "securityGroupTag": "string",
            "linkSpeed": 0,
            "bridgeVMMode": "string",
            "band": "string",
            "ssid": "string",
            "authType": "string",
            "wlcName": "string",
            "wlcId": "string",
            "apMac": "string",
            "apEthernetMac": "string",
            "apMode": "string",
            "radioId": 0,
            "channel": "string",
            "channelWidth": "string",
            "protocol": "string",
            "protocolCapability": "string",
            "upnId": "string",
            "upnName": "string",
            "upnOwner": "string",
            "upnDuid": "string",
            "rssi": 0,
            "snr": 0,
            "dataRate": 0,
            "isIosAnalyticsCapable": true
          },
          "onboarding": {
            "avgRunDuration": 0,
            "maxRunDuration": 0,
            "avgAssocDuration": 0,
            "maxAssocDuration": 0,
            "avgAuthDuration": 0,
            "maxAuthDuration": 0,
            "avgDhcpDuration": 0,
            "maxDhcpDuration": 0,
            "maxRoamingDuration": 0,
            "aaaServerIp": "string",
            "dhcpServerIp": "string",
            "onboardingTime": 0,
            "authDoneTime": 0,
            "assocDoneTime": 0,
            "dhcpDoneTime": 0,
            "roamingTime": 0,
            "failedRoamingCount": 0,
            "successfulRoamingCount": 0,
            "totalRoamingAttempts": 0,
            "assocFailureReason": "string",
            "aaaFailureReason": "string",
            "dhcpFailureReason": "string",
            "otherFailureReason": "string",
            "latestFailureReason": "string"
          },
          "latency": {
            "video": 0,
            "voice": 0,
            "bestEffort": 0,
            "background": 0
          },
          "aggregateAttributes": [
            {
              "name": "string",
              "function": "string",
              "value": 0
            }
          ]
        }
      ],
      "page": {
        "limit": 0,
        "offset": 0,
        "count": 0,
        "sortBy": [
          {
            "name": "string",
            "order": "string"
          }
        ]
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: site_health_summaries_info
short_description: Information module for Site Health Summaries
description:
  - Get all Site Health Summaries.
  - Get Site Health Summaries by id.
  - Get a health summary for a specific site by providing the unique site id in the url path. - > Get a paginated list of
    site health summaries. Use the available query parameters to identify a subset of sites you want health summaries for.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  startTime:
    description:
      - >
        StartTime query parameter. Start time from which API queries the data set related to the resource. It
        must be specified in UNIX epochtime in milliseconds. Value is inclusive. If `startTime` is not provided,
        API will default to current time.
    type: float
  endTime:
    description:
      - >
        EndTime query parameter. End time to which API queries the data set related to the resource. It must be
        specified in UNIX epochtime in milliseconds. Value is inclusive.
    type: float
  limit:
    description:
      - Limit query parameter. Maximum number of records to return.
    type: int
  offset:
    description:
      - >
        Offset query parameter. Specifies the starting point within all records returned by the API. It's one
        based offset. The starting value is 1.
    type: int
  sortBy:
    description:
      - SortBy query parameter. A field within the response to sort by.
    type: str
  order:
    description:
      - Order query parameter. The sort order of the field ascending or descending.
    type: str
  siteHierarchy:
    description:
      - >
        SiteHierarchy query parameter. The full hierarchical breakdown of the site tree starting from Global
        site name and ending with the specific site name. The Root site is named "Global" (Ex.
        `Global/AreaName/BuildingName/FloorName`) This field supports wildcard asterisk (`*`) character search
        support. E.g. `*/San*, */San, /San*` Examples `?siteHierarchy=Global/AreaName/BuildingName/FloorName`
        (single siteHierarchy requested) `?siteHierarchy=Global/AreaName/BuildingName/FloorName&siteHierarchy=Gl
        obal/AreaName2/BuildingName2/FloorName2` (multiple siteHierarchies requested).
    type: str
  siteHierarchyId:
    description:
      - >
        SiteHierarchyId query parameter. The full hierarchy breakdown of the site tree in id form starting from
        Global site UUID and ending with the specific site UUID. (Ex.
        `globalUuid/areaUuid/buildingUuid/floorUuid`) This field supports wildcard asterisk (`*`) character
        search support. E.g. `*uuid*, *uuid, uuid*` Examples
        `?siteHierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid `(single siteHierarchyId requested) `?siteH
        ierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid&siteHierarchyId=globalUuid/areaUuid2/buildingUuid2
        /floorUuid2` (multiple siteHierarchyIds requested).
    type: str
  siteType:
    description:
      - >
        SiteType query parameter. The type of the site. A site can be an area, building, or floor. Default when
        not provided will be `floor,building,area` Examples `?siteType=area` (single siteType requested)
        `?siteType=area&siteType=building&siteType=floor` (multiple siteTypes requested).
    type: str
  id:
    description:
      - >
        Id query parameter. The list of entity Uuids. (Ex."6bef213c-19ca-4170-8375-b694e251101c") Examples
        id=6bef213c-19ca-4170-8375-b694e251101c (single entity uuid requested) id=6bef213c-19ca-4170-8375-
        b694e251101c&id=32219612-819e-4b5e-a96b-cf22aca13dd9&id=2541e9a7-b80d-4955-8aa2-79b233318ba0 (multiple
        entity uuid with '&' separator).
    type: str
  view:
    description:
      - >
        View query parameter. The specific summary view being requested. This is an optional parameter which can
        be passed to get one or more of the specific health data summaries associated with sites. ### Response
        data proviced by each view 1. **site** id, siteHierarchy, siteHierarchyId, siteType, latitude, longitude
        2. **network** id, networkDeviceCount, networkDeviceGoodHealthCount,wirelessDeviceCount,
        wirelessDeviceGoodHealthCount, accessDeviceCount, accessDeviceGoodHealthCount, coreDeviceCount,
        coreDeviceGoodHealthCount, distributionDeviceCount, distributionDeviceGoodHealthCount,
        routerDeviceCount, routerDeviceGoodHealthCount, apDeviceCount, apDeviceGoodHealthCount, wlcDeviceCount,
        wlcDeviceGoodHealthCount, switchDeviceCount, switchDeviceGoodHealthCount,
        networkDeviceGoodHealthPercentage, accessDeviceGoodHealthPercentage, coreDeviceGoodHealthPercentage,
        distributionDeviceGoodHealthPercentage, routerDeviceGoodHealthPercentage, apDeviceGoodHealthPercentage,
        wlcDeviceGoodHealthPercentage, switchDeviceGoodHealthPercentage, wirelessDeviceGoodHealthPercentage 3.
        **client** id, clientCount, clientGoodHealthCount, wiredClientCount, wirelessClientCount,
        wiredClientGoodHealthCount, wirelessClientGoodHealthCount, clientGoodHealthPercentage,
        wiredClientGoodHealthPercentage, wirelessClientGoodHealthPercentage, clientDataUsage 4. **issue** id,
        p1IssueCount, p2IssueCount, p3IssueCount, p4IssueCount, issueCount When this query parameter is not
        added the default summaries are **site,client,network,issue** Examples view=client (single view
        requested) view=client&view=network&view=issue (multiple views requested).
    type: str
  attribute:
    description:
      - >
        Attribute query parameter. Supported Attributes id, siteHierarchy, siteHierarchyId, siteType, latitude,
        longitude, networkDeviceCount, networkDeviceGoodHealthCount,wirelessDeviceCount,
        wirelessDeviceGoodHealthCount, accessDeviceCount, accessDeviceGoodHealthCount, coreDeviceCount,
        coreDeviceGoodHealthCount, distributionDeviceCount, distributionDeviceGoodHealthCount,
        routerDeviceCount, routerDeviceGoodHealthCount, apDeviceCount, apDeviceGoodHealthCount, wlcDeviceCount,
        wlcDeviceGoodHealthCount, switchDeviceCount, switchDeviceGoodHealthCount,
        networkDeviceGoodHealthPercentage, accessDeviceGoodHealthPercentage, coreDeviceGoodHealthPercentage,
        distributionDeviceGoodHealthPercentage, routerDeviceGoodHealthPercentage, apDeviceGoodHealthPercentage,
        wlcDeviceGoodHealthPercentage, switchDeviceGoodHealthPercentage, wirelessDeviceGoodHealthPercentage,
        clientCount, clientGoodHealthCount, wiredClientCount, wirelessClientCount, wiredClientGoodHealthCount,
        wirelessClientGoodHealthCount, clientGoodHealthPercentage, wiredClientGoodHealthPercentage,
        wirelessClientGoodHealthPercentage, clientDataUsage, p1IssueCount, p2IssueCount, p3IssueCount,
        p4IssueCount, issueCount If length of attribute list is too long, please use 'view' param instead.
        Examples attribute=siteHierarchy (single attribute requested)
        attribute=siteHierarchy&attribute=clientCount (multiple attributes requested).
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Sites ReadListOfSiteHealthSummaries
    description: Complete reference of the ReadListOfSiteHealthSummaries API.
    link: https://developer.cisco.com/docs/dna-center/#!read-list-of-site-health-summaries
  - name: Cisco DNA Center documentation for Sites ReadSiteHealthSummaryDataBySiteId
    description: Complete reference of the ReadSiteHealthSummaryDataBySiteId API.
    link: https://developer.cisco.com/docs/dna-center/#!read-site-health-summary-data-by-site-id
notes:
  - SDK Method used are
    sites.Sites.read_list_of_site_health_summaries,
    sites.Sites.read_site_health_summary_data_by_site_id,
  - Paths used are
    get /dna/data/api/v1/siteHealthSummaries,
    get /dna/data/api/v1/siteHealthSummaries/{id},
"""

EXAMPLES = r"""
---
- name: Get all Site Health Summaries
  cisco.dnac.site_health_summaries_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    startTime: 0
    endTime: 0
    limit: 0
    offset: 0
    sortBy: string
    order: string
    siteHierarchy: string
    siteHierarchyId: string
    siteType: string
    id: string
    view: string
    attribute: string
  register: result
- name: Get Site Health Summaries by id
  cisco.dnac.site_health_summaries_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    startTime: 0
    endTime: 0
    view: string
    attribute: string
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "id": "string",
        "siteHierarchy": "string",
        "siteHierarchyId": "string",
        "siteType": "string",
        "latitude": 0,
        "longitude": 0,
        "networkDeviceGoodHealthPercentage": 0,
        "networkDeviceGoodHealthCount": 0,
        "clientGoodHealthCount": 0,
        "clientGoodHealthPercentage": 0,
        "wiredClientGoodHealthPercentage": 0,
        "wirelessClientGoodHealthPercentage": 0,
        "clientCount": 0,
        "wiredClientCount": 0,
        "wirelessClientCount": 0,
        "wiredClientGoodHealthCount": 0,
        "wirelessClientGoodHealthCount": 0,
        "networkDeviceCount": 0,
        "accessDeviceCount": 0,
        "accessDeviceGoodHealthCount": 0,
        "coreDeviceCount": 0,
        "coreDeviceGoodHealthCount": 0,
        "distributionDeviceCount": 0,
        "distributionDeviceGoodHealthCount": 0,
        "routerDeviceCount": 0,
        "routerDeviceGoodHealthCount": 0,
        "wirelessDeviceCount": 0,
        "wirelessDeviceGoodHealthCount": 0,
        "apDeviceCount": 0,
        "apDeviceGoodHealthCount": 0,
        "wlcDeviceCount": 0,
        "wlcDeviceGoodHealthCount": 0,
        "switchDeviceCount": 0,
        "switchDeviceGoodHealthCount": 0,
        "accessDeviceGoodHealthPercentage": 0,
        "coreDeviceGoodHealthPercentage": 0,
        "distributionDeviceGoodHealthPercentage": 0,
        "routerDeviceGoodHealthPercentage": 0,
        "apDeviceGoodHealthPercentage": 0,
        "wlcDeviceGoodHealthPercentage": 0,
        "switchDeviceGoodHealthPercentage": 0,
        "wirelessDeviceGoodHealthPercentage": 0,
        "clientDataUsage": 0,
        "p1IssueCount": 0,
        "p2IssueCount": 0,
        "p3IssueCount": 0,
        "p4IssueCount": 0,
        "issueCount": 0
      },
      "version": "string"
    }
"""
